@@ -151,7 +151,9 @@ enum XNEE_OPTION_KEYS
     XNEE_EXT_REQ_MAJ_STR_KEY  ,
     XNEE_EXT_REQ_MIN_STR_KEY  ,
     XNEE_EXT_REP_MAJ_STR_KEY  ,
-    XNEE_EXT_REP_MIN_STR_KEY      
+    XNEE_EXT_REP_MIN_STR_KEY  ,
+    XNEE_RETYPE_PRESS_DELAY   ,
+    XNEE_RETYPE_RELEASE_DELAY
   };
 
 
